onReady method
Called 1 frame after onInit(). It is the perfect place to enter navigation events, like snackbar, dialogs, or a new route, or async request.
Implementation
@override
void onReady() async {
// if (cameras.isEmpty) {
// status.value = BaseStatus(
// message: 'No camera found',
// state: AppState.pop,
// );
// }
super.onReady();
final currentPos = await LocationServices.getLocation();
currentLocation = await LocationServices.getLocationInfo(
currentPos?.latitude,
currentPos?.longitude,
);
}