$AssetsIconsGen class
Constructors
- $AssetsIconsGen()
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- icCamera → SvgGenImage
-
File path: assets/icons/ic_camera.svg
no setter
- icCheck → SvgGenImage
-
File path: assets/icons/ic_check.svg
no setter
- icCheckCircle → SvgGenImage
-
File path: assets/icons/ic_check_circle.svg
no setter
- icCheckFilled → SvgGenImage
-
File path: assets/icons/ic_check_filled.svg
no setter
- icErrorFilled → SvgGenImage
-
File path: assets/icons/ic_error_filled.svg
no setter
- icInfoFilled → SvgGenImage
-
File path: assets/icons/ic_info_filled.svg
no setter
- icInfoFilledCopy → SvgGenImage
-
File path: assets/icons/ic_info_filled copy.svg
no setter
- icWarning → SvgGenImage
-
File path: assets/icons/ic_warning.svg
no setter
- icWarningFilled → SvgGenImage
-
File path: assets/icons/ic_warning_filled.svg
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
values
→ List<
SvgGenImage> -
List of all assets
no setter
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited